"
" Usage guide
"
" To install all plugins on fresh install -> :PlugInstall
" To install LSP language server on new file extention: :LspServerInstall
"
" Backup (works with Vim8 and Neovim)
"
" tar -czvf jwalters_nvim_lite.tar.gz --exclude '*plugged*' ./.config/nvim .vimrc .vim
" tar -czvf jwalters_nvim_full.tar.gz ./.config/nvim .vimrc .vim
"

" Auto indent
set smartindent

" Tabs should be 4 space characters
set tabstop=4
set shiftwidth=4
set expandtab

" Line numbers
set nu

" Don't wrap lines
set nowrap

"" Plugged
call plug#begin('~/.config/nvim/plugged')
Plug 'preservim/nerdtree'
Plug 'ctrlpvim/ctrlp.vim'
Plug 'ervandew/supertab'
"" LSP Language server
Plug 'prabirshrestha/async.vim'
Plug 'prabirshrestha/vim-lsp'
Plug 'mattn/vim-lsp-settings'
Plug 'prabirshrestha/asyncomplete.vim'
Plug 'prabirshrestha/asyncomplete-lsp.vim'
call plug#end()

" Auto start NERDTree if open without file
autocmd vimenter * if !argc() | NERDTree | only | endif

" Load wombat color scheme
colorscheme wombat256

" Delete all trailing whitespaces on save
autocmd BufWritePre * :%s/\s\+$//e

" Status line
set laststatus=2
set statusline=%F[%{strlen(&fenc)?&fenc:'none'},%{&ff}]%h%m%r%y%=%c,%l/%L\ %P

"" CtrlP settings
let g:ctrlp_max_files=0
let g:ctrlp_custom_ignore='.git$\|node_modules\|build'"
let g:ctrlp_user_command = ['.git', 'cd %s && git ls-files']

"" Highlight searches
set hlsearch

"" Highlight column 80
set colorcolumn=80

"" Show hidden files
let NERDTreeShowHidden=1

"" Disable swap files
set nobackup
set nowritebackup

"" LSP Language Server
"" Run 'LspInstallServer' to install the server for the language
function! s:on_lsp_buffer_enabled() abort
    setlocal omnifunc=lsp#complete
    setlocal signcolumn=yes
    nmap <buffer> gd <plug>(lsp-definition)
    " refer to doc to add more commands
endfunction

augroup lsp_install
    au!
    " call s:on_lsp_buffer_enabled only for languages that has the server registered.
    autocmd User lsp_buffer_enabled call s:on_lsp_buffer_enabled()
augroup END
